@@ -1,9 +1,8 @@
 package Statocles::Page;
 # ABSTRACT: Render documents into HTML
-$Statocles::Page::VERSION = '0.041';
+$Statocles::Page::VERSION = '0.042';
 use Statocles::Base 'Role';
 use Statocles::Template;
-use Text::Markdown;
 
 
 has site => (
@@ -48,8 +47,8 @@ has _links => (
 
 has markdown => (
     is => 'ro',
-    isa => InstanceOf['Text::Markdown'],
-    default => sub { Text::Markdown->new },
+    isa => HasMethods['markdown'],
+    default => sub { $_[0]->site->markdown },
 );
 
 
@@ -123,7 +122,7 @@ Statocles::Page - Render documents into HTML
 
 =head1 VERSION
 
-version 0.041
+version 0.042
 
 =head1 DESCRIPTION
 
@@ -165,7 +164,10 @@ attributes are:
 
 =head2 markdown
 
-The L<Text::Markdown> object to render document Markdown.
+The markdown object to render document Markdown. Defaults to L<the markdown
+attribute from the Site object|Statocles::Site/markdown>.
+
+Any object with a "markdown" method will work.
 
 =head2 template
 
