@@ -1,10 +1,17 @@
 package Statocles::Plugin::LinkCheck;
 # ABSTRACT: Check links and images for validity during build
-$Statocles::Plugin::LinkCheck::VERSION = '0.041';
+$Statocles::Plugin::LinkCheck::VERSION = '0.042';
 use Statocles::Base 'Class';
 use Mojo::DOM;
 
 
+has ignore => (
+    is => 'ro',
+    isa => ArrayRef[Str],
+    default => sub { [] },
+);
+
+
 sub check_pages {
     my ( $self, $event ) = @_;
 
@@ -34,6 +41,7 @@ sub check_pages {
     for my $link_url ( keys %links ) {
         $link_url .= 'index.html' if $link_url =~ m{/$};
         next if $page_paths{ $link_url } || $page_paths{ "$link_url/index.html" };
+        next if grep { $link_url =~ /^$_/ } @{ $self->ignore };
         for my $page_url ( keys %{ $links{ $link_url } } ) {
             $event->emitter->log->warn( "URL broken on $page_url: '$link_url' not found" );
         }
@@ -53,7 +61,7 @@ Statocles::Plugin::LinkCheck - Check links and images for validity during build
 
 =head1 VERSION
 
-version 0.041
+version 0.042
 
 =head1 SYNOPSIS
 
@@ -70,6 +78,18 @@ version 0.041
 This plugin checks all of the links and images to ensure they exist. If something
 is missing, this plugin will write a warning to the screen.
 
+=head1 ATTRIBUTES
+
+=head2 ignore
+
+An array of URL patterns to ignore. These are interpreted as regular expressions,
+and are anchored to the beginning of the URL.
+
+For example:
+
+    /broken     will match "/broken.html" "/broken/page.html" but not "/page/broken"
+    .*/broken   will match "/broken.html" "/broken/page.html" and "/page/broken"
+
 =head1 METHODS
 
 =head2 check_pages( event )
