@@ -1,8 +1,9 @@
 package Statocles::Site;
 # ABSTRACT: An entire, configured website
-$Statocles::Site::VERSION = '0.041';
+$Statocles::Site::VERSION = '0.042';
 use Statocles::Base 'Class', 'Emitter';
 use Scalar::Util qw( blessed );
+use Text::Markdown;
 use Mojo::URL;
 use Mojo::DOM;
 use Mojo::Log;
@@ -111,6 +112,13 @@ has log => (
     },
 );
 
+
+has markdown => (
+    is => 'ro',
+    isa => HasMethods['markdown'],
+    default => sub { Text::Markdown->new },
+);
+
 # The current deploy we're writing to
 has _write_deploy => (
     is => 'rw',
@@ -172,6 +180,12 @@ sub build {
         push @pages, @app_pages;
     }
 
+    $self->emit(
+        'before_build_write',
+        class => 'Statocles::Event::Pages',
+        pages => \@pages,
+    );
+
     # Rewrite page content to add base URL
     my $base_url = $self->base_url;
     if ( $self->_write_deploy ) {
@@ -275,7 +289,7 @@ Statocles::Site - An entire, configured website
 
 =head1 VERSION
 
-version 0.041
+version 0.042
 
 =head1 SYNOPSIS
 
@@ -367,6 +381,13 @@ to themes like header image URLs.
 
 A L<Mojo::Log> object to write logs to. Defaults to STDERR.
 
+=head2 markdown
+
+The Text::Markdown object to use to turn Markdown into HTML. Defaults to a
+plain Text::Markdown object.
+
+Any object with a "markdown" method will work here.
+
 =head1 METHODS
 
 =head2 BUILD
@@ -402,6 +423,17 @@ Get the full URL to the given path by prepending the C<base_url>.
 
 The site object exposes the following events.
 
+=head2 before_build_write
+
+This event is fired after the pages have been built by the apps, but before
+any page is written to the C<build_store>.
+
+You can use this event to add new pages or edit the pages already created.
+
+The event will be a
+L<Statocles::Event::Pages|Statocles::Event/Statocles::Event::Pages> object
+containing all the pages built by the apps.
+
 =head2 build
 
 This event is fired after the site has been built and the pages written to the
